% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/HCgglasso.R
\name{HCgglasso}
\alias{HCgglasso}
\title{Run hierarchical clustering following by a group-lasso on all the different partition.}
\usage{
HCgglasso(X, y, hc = NULL, lambda = NULL, weightLevel = NULL,
  weightSizeGroup = NULL, intercept = TRUE, verbose = FALSE, ...)
}
\arguments{
\item{X}{matrix of size n*p}

\item{y}{vector of size n}

\item{hc}{output of \code{\link{hclust}} function. If not provided, \code{\link{hclust}} is run with ward.D2 method}

\item{lambda}{lambda values for group lasso. If not provided, the function generates its own values of lambda}

\item{weightLevel}{a vector of size p for each level of the hierarchy. A zero indicates that the level will be ignored. If not provided, use 1/(height between 2 successive levels)}

\item{weightSizeGroup}{a vector of size 2*p-1 containing the weight for each group. Default is the square root of the size of each group}

\item{intercept}{should an intercept be included in the model ?}

\item{verbose}{print some information}

\item{...}{Others parameters for \code{\link{gglasso}} function}
}
\value{
a HCgglasso object containing :
\describe{
  \item{lambda}{lambda values}
  \item{b0}{intercept values for \code{lambda}}
  \item{beta}{A list containing the values of estimated coefficients for each values of \code{lambda}}
  \item{var}{A list containing the index of selected variables for each values of \code{lambda}}
  \item{group}{A list containing the values index of selected groups for each values of \code{lambda}}
  \item{nVar}{A vector containing the number of non zero coefficients for each values of \code{lambda}}
  \item{nGroup}{A vector containing the number of non zero groups for each values of \code{lambda}}
  \item{structure}{A list containing 3 vectors. var : all variables used. group : associated groups. 
  weight : weight associated with the different groups.
  level : for each group, the corresponding level of the hierarchy where it appears and disappears. 3 indicates the level with a partition of 3 groups.}
  \item{time}{computation time}
  \item{dim}{dimension of \code{X}}
  \item{hc}{Output of hierarchical clustering}
  \item{call}{Code executed by user}
}
}
\description{
Run hierarchical clustering following by a group-lasso on all the different partition.
}
\examples{
set.seed(42)
X = simuBlockGaussian(50,12,5,0.7)
y = drop(X[,c(2,7,12)]\%*\%c(2,2,-2)+rnorm(50,0,0.5))
res = HCgglasso(X,y)

}
\author{
Quentin Grimonprez
}
\seealso{
\link{cv.HCgglasso}, \link{stability.HCgglasso}, \link{listToMatrix}, \link{predict.HCgglasso}, \link{coef.HCgglasso}, \link{plot.cv.HCgglasso}
}

